Pwirth has uploaded a new change for review.
https://gerrit.wikimedia.org/r/301357
Change subject: BSExtensionManager: Changed global name for BlueSpice extensions
......................................................................
BSExtensionManager: Changed global name for BlueSpice extensions
Change-Id: Id8b240e1a5ad375131ebb5aea48e587517a9fb51
---
M includes/DefaultSettings.php
M includes/ExtensionManager.class.php
2 files changed, 9 insertions(+), 9 deletions(-)
git pull
ssh://gerrit.wikimedia.org:29418/mediawiki/extensions/BlueSpiceFoundation
refs/changes/57/301357/1
diff --git a/includes/DefaultSettings.php b/includes/DefaultSettings.php
index 047935d..b495689 100644
--- a/includes/DefaultSettings.php
+++ b/includes/DefaultSettings.php
@@ -222,4 +222,4 @@
/**
* BsExtensionManager extension registration
*/
-$bsgBSExtensions = array();
\ No newline at end of file
+$bsgExtensions = array();
\ No newline at end of file
diff --git a/includes/ExtensionManager.class.php
b/includes/ExtensionManager.class.php
index 4ff9fe1..c5d530a 100644
--- a/includes/ExtensionManager.class.php
+++ b/includes/ExtensionManager.class.php
@@ -67,9 +67,9 @@
}
/**
* DEPRECATED: Use global $bsgBSExtensions instead.
* Define $bsgBSExtensions in extension.json
* "bsgBSExtensions": {
* "ExtName": {
* "className": "ExtClass",
* "extPath": "/PackagePath/ExtDir",
@@ -104,7 +104,7 @@
$sClassName = "Bs$sClassName";
}
- $GLOBALS['bsgBSExtensions'][$name] = array(
+ $GLOBALS['bsgExtensions'][$name] = array(
'className' => $sClassName,
'extPath' => $extPath,
'deprecatedSince' => '2.27.0',
@@ -158,16 +158,16 @@
public static function initialiseExtensions( $oCore ) {
wfProfileIn( 'Performance: ' . __METHOD__ );
$aBSExtFromJSON =
ExtensionRegistry::getInstance()->getAttribute(
- 'bsgBSExtensions'
+ 'bsgExtensions'
);
if( !empty( $aBSExtFromJSON ) ) {
- $GLOBALS['bsgBSExtensions'] = array_merge_recursive(
- $GLOBALS['bsgBSExtensions'],
+ $GLOBALS['bsgExtensions'] = array_merge_recursive(
+ $GLOBALS['bsgExtensions'],
$aBSExtFromJSON
);
}
- foreach( $GLOBALS['bsgBSExtensions'] as $sExtName => $aConfig )
{
+ foreach( $GLOBALS['bsgExtensions'] as $sExtName => $aConfig ) {
self::$prRegisteredExtensions[$sExtName]
= self::makeExtensionConfig( $sExtName,
$aConfig );
@@ -67,9 +67,9 @@
}
/**
- * DEPRECATED: Use global $bsgBSExtensions instead.
- * Define $bsgBSExtensions in extension.json
- * "bsgBSExtensions": {
+ * DEPRECATED: Use global $bsgExtensions instead.
+ * Define $bsgExtensions in extension.json
+ * "bsgExtensions": {
* "ExtName": {
* "className": "ExtClass",
}
--
To view, visit https://gerrit.wikimedia.org/r/301357
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings
Gerrit-MessageType: newchange
Gerrit-Change-Id: Id8b240e1a5ad375131ebb5aea48e587517a9fb51
Gerrit-PatchSet: 1
Gerrit-Project: mediawiki/extensions/BlueSpiceFoundation
Gerrit-Branch: master
Gerrit-Owner: Pwirth <[email protected]>
_______________________________________________
MediaWiki-commits mailing list
[email protected]
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits